﻿using System.Collections;
using System.Collections.Generic;
using Unity.Collections;
using UnityEngine;

public class TerrainMaster : MonoBehaviour
{
    [Header("User settings")]
    public List<Octave> octaves;

    public Vector2 initialCrawlPosition;
    
    [SerializeField]
    private bool generateNewCrawlPosition;

    [Header("Autogenerated values")]
	public Dictionary<Vector2Int, TerrainChunker> chunkers = new();

    private void Start()
    {
        for (int x = -1; x < 2; x++)
        {
            for (int y = -1; y < 2; y++)
            {
                Vector2Int gridPos = new(x, y);
                GameObject chunkGO = new();
                TerrainChunker chunker = chunkGO.AddComponent<TerrainChunker>();
                chunker.transform.parent = transform;
                chunker.Initialize(this, gridPos, initialCrawlPosition);
                chunkers[gridPos] = chunker;
            }
        }
    }

    public void UpdateGridPosition(Vector2Int gridPositionCenter)
    {
        for (int x = -1; x < 2; x++)
        {
            for (int y = -1; y < 2; y++)
            {
                Vector2Int gridPos = new Vector2Int(x, y) + gridPositionCenter;
                // Bound x.
                int bndX = (gridPos.x + 1) % 2 - 1;
                int bndY = (gridPos.y + 1) % 2 - 1;
                Vector2Int bndGridPos = new(bndX, bndY);

                chunkers[bndGridPos].UpdatePositions(gridPos);
            }
        }
    }

    private void OnValidate()
    {
        if (generateNewCrawlPosition)
        {
            generateNewCrawlPosition = false;
            initialCrawlPosition = RNG.GetRandomVector2(-2500, 2500);
        }
    }
}